@@ -1,6 +1,6 @@
 ;;; forge-commands.el --- Commands  -*- lexical-binding:t -*-
 
-;; Copyright (C) 2018-2025 Jonas Bernoulli
+;; Copyright (C) 2018-2026 Jonas Bernoulli
 
 ;; Author: Jonas Bernoulli <emacs.forge@jonas.bernoulli.dev>
 ;; Maintainer: Jonas Bernoulli <emacs.forge@jonas.bernoulli.dev>
@@ -73,10 +73,10 @@ Takes the pull-request as only argument and must return a directory."
     ("c f" "fork or remote" forge-fork)]
    [:description (lambda ()
                    (cond
-                    ((forge-get-repository :tracked?) "Actions")
-                    ((or (magit-gitdir) (forge-repository-at-point))
-                     "Forge does not yet track this repository")
-                    ("Not inside a Git repository")))
+                     ((forge-get-repository :tracked?) "Actions")
+                     ((or (magit-gitdir) (forge-repository-at-point))
+                      "Forge does not yet track this repository")
+                     ("Not inside a Git repository")))
     ("/ a" forge-add-repository
      :description (lambda () (let ((repo (forge-get-repository :stub?)))
                           (if (or (not repo)
@@ -288,11 +288,11 @@ argument also offer closed pull-requests."
 (defun forge-browse-commit (commit)
   "Read a COMMIT and visit it using a browser."
   (interactive
-   (list (or (magit-completing-read "Browse commit"
-                                    (magit-list-branch-names)
-                                    nil nil nil 'magit-revision-history
-                                    (magit-branch-or-commit-at-point))
-             (user-error "Nothing selected"))))
+    (list (or (magit-completing-read "Browse commit"
+                                     (magit-list-branch-names)
+                                     nil nil nil 'magit-revision-history
+                                     (magit-branch-or-commit-at-point))
+              (user-error "Nothing selected"))))
   (browse-url (forge-get-url :commit commit)))
 
 ;;;###autoload
@@ -326,6 +326,10 @@ jumping to a line, always use a commit hash as part of the URL.  From
 a file in the worktree with no active region, instead use the branch
 name as part of the URL, unless a prefix argument is used.
 
+When invoked from a Dired buffer, visit the blob at point without
+prompting. If a prefix argument is used, the commit hash is included
+in the URL.
+
 When invoked from any other buffer, prompt the user for a branch or
 commit, and for a file."
   (interactive (forge--browse-blob-args))
@@ -374,7 +378,9 @@ commit, and for a file."
       (and$ (magit-file-at-point)            (forge-get-url :blob nil $))
       (forge-post-at-point)
       (forge-current-topic)
-      (and (or magit-buffer-file-name buffer-file-name)
+      (and (or magit-buffer-file-name
+               buffer-file-name
+               (derived-mode-p 'dired-mode))
            (apply #'forge-get-url :blob (forge--browse-blob-args)))
       (and magit-buffer-revision
            (forge-get-url :commit magit-buffer-revision))
@@ -382,19 +388,23 @@ commit, and for a file."
 
 (defun forge--browse-blob-args ()
   (cond
-   (magit-buffer-file-name
-    `(,(or magit-buffer-refname magit-buffer-revision)
-      ,(magit-file-relative-name magit-buffer-file-name)
-      ,@(magit-file-region-line-numbers)
-      ,current-prefix-arg))
-   (buffer-file-name
-    `(nil
-      ,(magit-file-relative-name buffer-file-name)
-      ,@(magit-file-region-line-numbers)
-      ,current-prefix-arg))
-   ((let ((commit (magit-read-local-branch-or-commit
-                   "Browse file from commit")))
-      (list commit (magit-read-file-from-rev commit "Browse file"))))))
+    (magit-buffer-file-name
+     `(,(or magit-buffer-refname magit-buffer-revision)
+       ,(magit-file-relative-name magit-buffer-file-name)
+       ,@(magit-file-region-line-numbers)
+       ,current-prefix-arg))
+    (buffer-file-name
+     `(nil
+       ,(magit-file-relative-name buffer-file-name)
+       ,@(magit-file-region-line-numbers)
+       ,current-prefix-arg))
+    ((derived-mode-p 'dired-mode)
+     `(nil
+       ,(magit-file-relative-name (dired-get-filename))
+       ,current-prefix-arg))
+    ((let ((commit (magit-read-local-branch-or-commit
+                    "Browse file from commit")))
+       (list commit (magit-read-file-from-rev commit "Browse file"))))))
 
 ;;;; Urls
 
@@ -469,7 +479,7 @@ commit, and for a file."
 (cl-defmethod forge-get-url ((notify forge-notification))
   (oref notify url))
 
- ;; Transitional kludge for the infamous package.el defect.
+;; Transitional kludge for the infamous package.el defect.
 (require 'forge-forgejo)
 
 (cl-defmethod forge-format-blob-lines ((repo forge-repository) line end)
@@ -556,12 +566,12 @@ With prefix argument MENU, also show the topic menu."
   (interactive (list current-prefix-arg))
   (forge-topic-setup-buffer (forge-topic-at-point))
   (cond
-   ((eq transient-current-command 'forge-topic-menu)
-    (setq forge--quit-keep-topic-menu t))
-   ((or menu
-        (memq transient-current-command
-              '(forge-topics-menu forge-notifications-menu)))
-    (transient-setup 'forge-topic-menu))))
+    ((eq transient-current-command 'forge-topic-menu)
+     (setq forge--quit-keep-topic-menu t))
+    ((or menu
+         (memq transient-current-command
+               '(forge-topics-menu forge-notifications-menu)))
+     (transient-setup 'forge-topic-menu))))
 
 ;;;###autoload
 (defun forge-visit-this-repository ()
@@ -570,25 +580,25 @@ With prefix argument MENU, also show the topic menu."
   (let* ((repo (forge-repository-at-point))
          (worktree (forge-get-worktree repo)))
     (cond
-     ((and (eq transient-current-command 'forge-repositories-menu)
-           (forge-get-repository repo nil :tracked?))
-      (cond-let
-        ([buffer (get-buffer (forge-topics-buffer-name repo))]
-         (switch-to-buffer buffer)
-         (transient-setup 'forge-topics-menu))
-        ((forge-list-topics repo))))
-     (worktree
-      (magit-status-setup-buffer worktree))
-     ((forge-get-repository repo nil :tracked?)
-      (forge-list-topics repo))
-     ((user-error "Not tracked and location of clone is unknown")))))
+      ((and (eq transient-current-command 'forge-repositories-menu)
+            (forge-get-repository repo nil :tracked?))
+       (cond-let
+         ([buffer (get-buffer (forge-topics-buffer-name repo))]
+          (switch-to-buffer buffer)
+          (transient-setup 'forge-topics-menu))
+         ((forge-list-topics repo))))
+      (worktree
+       (magit-status-setup-buffer worktree))
+      ((forge-get-repository repo nil :tracked?)
+       (forge-list-topics repo))
+      ((user-error "Not tracked and location of clone is unknown")))))
 
 ;;; Create
 
 (defun forge-create-discussion (category)
   "Create a new discussion for the current repository."
   (interactive
-   (list (forge-read-topic-category nil "Category for new discussion")))
+    (list (forge-read-topic-category nil "Category for new discussion")))
   (forge--setup-post-buffer 'new-discussion #'forge--submit-create-discussion
     "new-discussion" "Create new discussion on %p"
     `((forge--buffer-category ,category))))
@@ -669,12 +679,12 @@ point is currently on."
   (unless (derived-mode-p 'forge-topic-mode)
     (user-error "This command is only available from topic buffers"))
   (let* ((quote (cond
-                 ((not (magit-section-match 'post)) nil)
-                 ((use-region-p)
-                  (buffer-str (region-beginning) (region-end)))
-                 (quote
-                  (with-slots (content end) (magit-current-section)
-                    (string-trim (buffer-str content end))))))
+                  ((not (magit-section-match 'post)) nil)
+                  ((use-region-p)
+                   (buffer-str (region-beginning) (region-end)))
+                  (quote
+                   (with-slots (content end) (magit-current-section)
+                     (string-trim (buffer-str content end))))))
          (quote (and quote
                      (lambda ()
                        (goto-char (point-max))
@@ -935,10 +945,10 @@ This is like `forge-checkout-pullreq', except that it also
 creates a new worktree.  Please see the manual for more
 information."
   (interactive
-   (let ((id (forge-read-pullreq "Checkout pull request")))
-     (list (funcall forge-checkout-worktree-read-directory-function
-                    (forge-get-pullreq id))
-           id)))
+    (let ((id (forge-read-pullreq "Checkout pull request")))
+      (list (funcall forge-checkout-worktree-read-directory-function
+                     (forge-get-pullreq id))
+            id)))
   (when (and (file-exists-p path)
              (not (and (file-directory-p path)
                        (length= (directory-files path) 2))))
@@ -962,7 +972,7 @@ information."
       (user-error "The empty string isn't a valid path"))
     path))
 
-;;;###autoload (autoload 'forge-push-to-unnamed-pullreq "forge-commands" nil t)
+;;;###autoload(autoload 'forge-push-to-unnamed-pullreq "forge-commands" nil t)
 (transient-define-suffix forge-push-to-unnamed-pullreq (args)
   "Push the current branch to the branch on the contributor's fork.
 
@@ -1005,42 +1015,42 @@ number) and this command is made available as a substitute in the
 (defun forge-create-mark (name face description)
   "Define a new mark that topics can be marked with."
   (interactive
-   (list (read-string "Name: ")
-         (magit-read-char-case "Set appearance using " nil
-           (?n "a face [n]ame"
-               (read-face-name "Face name: "))
-           (?s "face [s]exp"
-               (read-from-minibuffer
-                "Face sexp: "
-                "(:background \"\" :foreground \"\" :box t)"
-                read-expression-map t)))
-         (let ((str (read-string "Description: ")))
-           (and (not (equal str "")) str))))
+    (list (read-string "Name: ")
+          (magit-read-char-case "Set appearance using " nil
+            (?n "a face [n]ame"
+                (read-face-name "Face name: "))
+            (?s "face [s]exp"
+                (read-from-minibuffer
+                 "Face sexp: "
+                 "(:background \"\" :foreground \"\" :box t)"
+                 read-expression-map t)))
+          (let ((str (read-string "Description: ")))
+            (and (not (equal str "")) str))))
   (forge-sql [:insert-into mark :values $v1]
              (vector nil (forge--uuid) name face description)))
 
 (defun forge-edit-mark (id name face description)
   "Define a new mark that topics can be marked with."
   (interactive
-   (pcase-let*
-       ((marks (forge-sql [:select [name id face description] :from mark]))
-        (`(,name ,id ,face ,description)
-         (assoc (completing-read "Edit mark" (mapcar #'car marks) nil t)
-                marks)))
-     (list id
-           (read-string "Name: " name)
-           (magit-read-char-case "Set appearance using " nil
-             (?n "a face [n]ame"
-                 (read-face-name "Face name: " (and (symbolp face) face)))
-             (?s "face [s]exp"
-                 (read-from-minibuffer
-                  "Face sexp: "
-                  (if (listp face)
-                      (format "%S" face)
-                    "(:background \"\" :foreground \"\" :box t)")
-                  read-expression-map t)))
-           (let ((str (read-string "Description: " nil nil description)))
-             (and (not (equal str "")) str)))))
+    (pcase-let*
+        ((marks (forge-sql [:select [name id face description] :from mark]))
+         (`(,name ,id ,face ,description)
+          (assoc (completing-read "Edit mark" (mapcar #'car marks) nil t)
+                 marks)))
+      (list id
+            (read-string "Name: " name)
+            (magit-read-char-case "Set appearance using " nil
+              (?n "a face [n]ame"
+                  (read-face-name "Face name: " (and (symbolp face) face)))
+              (?s "face [s]exp"
+                  (read-from-minibuffer
+                   "Face sexp: "
+                   (if (listp face)
+                       (format "%S" face)
+                     "(:background \"\" :foreground \"\" :box t)")
+                   read-expression-map t)))
+            (let ((str (read-string "Description: " nil nil description)))
+              (and (not (equal str "")) str)))))
   (forge-sql [:update mark
               :set (= [name face description] $v1)
               :where (= id $s2)]
@@ -1049,20 +1059,25 @@ number) and this command is made available as a substitute in the
 ;;; Remotely
 
 ;;;###autoload
-(defun forge-fork (fork remote)
+(defun forge-fork (fork remote all)
   "Fork the current repository to FORK and add it as a REMOTE.
+
 If the fork already exists, then that isn't an error; the remote
-is added anyway.  Currently this only supports Github and Gitlab."
+is added anyway.  Currently this only supports Github and Gitlab.
+
+With prefix argument ALL, fork all branches, not just the default
+branch.  On Gitlab it is not possible to fork only the default."
   (interactive
-   (let ((fork (magit-completing-read "Fork to"
-                                      (mapcar #'car forge-owned-accounts))))
-     (list fork
-           (read-string "Remote name: "
-                        (or (plist-get (cdr (assoc fork forge-owned-accounts))
-                                       'remote-name)
-                            fork)))))
+    (let ((fork (magit-completing-read "Fork to"
+                                       (mapcar #'car forge-owned-accounts))))
+      (list fork
+            (read-string "Remote name: "
+                         (or (plist-get (cdr (assoc fork forge-owned-accounts))
+                                        'remote-name)
+                             fork))
+            current-prefix-arg)))
   (let ((repo (forge-get-repository :stub)))
-    (forge--fork-repository repo fork)
+    (forge--fork-repository repo fork all)
     (magit-remote-add remote
                       (magit-clone--format-url (oref repo githost) fork
                                                (oref repo name))
@@ -1264,11 +1279,11 @@ upstream remote."
                (propertize (forge--scope 'topdir) 'face 'bold))
        (if-let* ((remote (forge--get-remote))
                  (url (magit-git-string "remote" "get-url" remote)))
-             (format (propertize "because %s is not on a host known to Forge."
-                                 'face 'transient-heading)
-                     (propertize url 'face 'bold))
-           (propertize "because no suitable remote was detected."
-                       'face 'transient-heading))))
+           (format (propertize "because %s is not on a host known to Forge."
+                               'face 'transient-heading)
+                   (propertize url 'face 'bold))
+         (propertize "because no suitable remote was detected."
+                     'face 'transient-heading))))
     ("r" forge-forge.remote :format " %k Try another %d %v" :face 'bold)
     ("h" "Learn how to configure another Github host"
      (lambda () (interactive) (info "(forge)Setup for Another Github Instance")))
@@ -1292,8 +1307,8 @@ upstream remote."
     ("s" "pulling only topics since <date>"
      (lambda (repo date)
        (interactive
-        (list (forge--scope 'repo)
-              (forge-read-date "Limit pulling to topics updated since: ")))
+         (list (forge--scope 'repo)
+               (forge-read-date "Limit pulling to topics updated since: ")))
        (forge-add-repository repo date)))
     ("i" "to allow pulling of individual topics"
      (lambda (repo)
@@ -1309,33 +1324,33 @@ upstream remote."
   (declare (interactive-only nil))
   (interactive)
   (cond
-   ((not repo)
-    (transient-setup 'forge-add-repository nil nil
-                     :scope (forge-add-repository--scope)))
-   ((stringp repo)
-    (transient-setup 'forge-add-repository nil nil
-                     :scope (forge-add-repository--scope repo)))
-   (t
-    (when-let*
-        ((_(not (eq limit :selective)))
-         (_(magit-git-config-p "forge.autoPull" t))
-         (remote  (oref repo remote))
-         (refspec (oref repo pullreq-refspec))
-         (default-directory (forge-get-worktree repo))
-         (_(and (not (member refspec (magit-get-all "remote" remote "fetch")))
-                (or (eq forge-add-pullreq-refspec t)
-                    (and (eq forge-add-pullreq-refspec 'ask)
-                         (y-or-n-p (format "Also add %S refspec? " refspec)))))))
-      (magit-call-git "config" "--add"
-                      (format "remote.%s.fetch" remote)
-                      refspec))
-    (setq repo (forge-get-repository repo nil :insert!))
-    (when (eq limit :selective)
-      (oset repo selective-p t)
-      (setq limit nil))
-    (forge--pull repo
-                 (and (not (forge-get-worktree repo)) #'ignore)
-                 limit))))
+    ((not repo)
+     (transient-setup 'forge-add-repository nil nil
+                      :scope (forge-add-repository--scope)))
+    ((stringp repo)
+     (transient-setup 'forge-add-repository nil nil
+                      :scope (forge-add-repository--scope repo)))
+    (t
+     (when-let*
+         ((_(not (eq limit :selective)))
+          (_(magit-git-config-p "forge.autoPull" t))
+          (remote  (oref repo remote))
+          (refspec (oref repo pullreq-refspec))
+          (default-directory (forge-get-worktree repo))
+          (_(and (not (member refspec (magit-get-all "remote" remote "fetch")))
+                 (or (eq forge-add-pullreq-refspec t)
+                     (and (eq forge-add-pullreq-refspec 'ask)
+                          (y-or-n-p (format "Also add %S refspec? " refspec)))))))
+       (magit-call-git "config" "--add"
+                       (format "remote.%s.fetch" remote)
+                       refspec))
+     (setq repo (forge-get-repository repo nil :insert!))
+     (when (eq limit :selective)
+       (oset repo selective-p t)
+       (setq limit nil))
+     (forge--pull repo
+                  (and (not (forge-get-worktree repo)) #'ignore)
+                  limit))))
 
 (defun forge-add-repository--scope (&optional directory)
   (let* ((repo      (if directory
@@ -1361,22 +1376,22 @@ upstream remote."
 (defun forge-add-some-repository (url)
   "Read a repository and add it to the database."
   (interactive
-   (let (ret url)
-     (while (not ret)
-       (setq url (magit-read-string-ns
-                  "Add repository to database (url, owner/name, or name)" url))
-       (unless (string-match-p "\\(://\\|@\\)" url)
-         (setq url (magit-clone--name-to-url url)))
-       (cond ((forge-get-repository url nil :tracked?)
-              (message "%s is already being tracked locally"
-                       (propertize url 'face 'bold))
-              (sit-for 3))
-             ((not (forge-get-repository url nil :valid?))
-              (message "%s does not exist or is inaccessible"
-                       (propertize url 'face 'bold))
-              (sit-for 3))
-             ((setq ret url))))
-     (list ret)))
+    (let (ret url)
+      (while (not ret)
+        (setq url (magit-read-string-ns
+                   "Add repository to database (url, owner/name, or name)" url))
+        (unless (string-match-p "\\(://\\|@\\)" url)
+          (setq url (magit-clone--name-to-url url)))
+        (cond ((forge-get-repository url nil :tracked?)
+               (message "%s is already being tracked locally"
+                        (propertize url 'face 'bold))
+               (sit-for 3))
+              ((not (forge-get-repository url nil :valid?))
+               (message "%s does not exist or is inaccessible"
+                        (propertize url 'face 'bold))
+               (sit-for 3))
+              ((setq ret url))))
+      (list ret)))
   (forge-add-repository url))
 
 ;;;###autoload
@@ -1384,9 +1399,9 @@ upstream remote."
   "Add all of USER's repositories from HOST to the database.
 This may take a while.  Only Github is supported at the moment."
   (interactive
-   (list (forge-read-host "Add repositories from Github host"
-                          'forge-github-repository)
-         (read-string "User: ")))
+    (list (forge-read-host "Add repositories from Github host"
+                           'forge-github-repository)
+          (read-string "User: ")))
   (forge--add-user-repos 'forge-github-repository host user))
 
 ;;;###autoload
@@ -1394,9 +1409,9 @@ This may take a while.  Only Github is supported at the moment."
   "Add all of ORGANIZATION's repositories from HOST to the database.
 This may take a while.  Only Github is supported at the moment."
   (interactive
-   (list (forge-read-host "Add repositories from Github host"
-                          'forge-github-repository)
-         (read-string "Organization: ")))
+    (list (forge-read-host "Add repositories from Github host"
+                           'forge-github-repository)
+          (read-string "Organization: ")))
   (forge--add-organization-repos 'forge-github-repository host organization))
 
 ;;; Cleanup
@@ -1405,12 +1420,12 @@ This may take a while.  Only Github is supported at the moment."
 (defun forge-remove-repository (repository)
   "Remove a repository from the database."
   (interactive
-   (pcase-let* ((repo (forge-read-repository "Remove repository from db"))
-                ((eieio githost owner name) repo))
-     (if (yes-or-no-p (format "Do you really want to remove \"%s/%s @%s\" %s? "
-                              owner name githost "from the database"))
-         (list repo)
-       (user-error "Abort"))))
+    (pcase-let* ((repo (forge-read-repository "Remove repository from db"))
+                 ((eieio githost owner name) repo))
+      (if (yes-or-no-p (format "Do you really want to remove \"%s/%s @%s\" %s? "
+                               owner name githost "from the database"))
+          (list repo)
+        (user-error "Abort"))))
   (closql-delete repository)
   (forge-refresh-buffer))
 
@@ -1430,12 +1445,12 @@ forge (the service).  Forge (the package) cannot automatically detect
 when that happens, because given how the APIs work, this would be too
 expensive."
   (interactive
-   (list (if-let* ((topics (magit-region-values '(issue pullreq) t))
-                   (_(magit-confirm 'remove-topics-locally nil
-                       "Delete %d topics locally" nil
-                       (mapcar #'forge--format-topic-line topics))))
-             topics
-           (forge-read-topic "Delete topic LOCALLY only"))))
+    (list (if-let* ((topics (magit-region-values '(issue pullreq) t))
+                    (_(magit-confirm 'remove-topics-locally nil
+                        "Delete %d topics locally" nil
+                        (mapcar #'forge--format-topic-line topics))))
+              topics
+            (forge-read-topic "Delete topic LOCALLY only"))))
   (if (listp topic)
       (progn (mapc #'closql-delete topic)
              (forge-refresh-buffer))
