@@ -1,6 +1,6 @@
 ;;; forge-github.el --- Github support  -*- lexical-binding:t -*-
 
-;; Copyright (C) 2018-2025 Jonas Bernoulli
+;; Copyright (C) 2018-2026 Jonas Bernoulli
 
 ;; Author: Jonas Bernoulli <emacs.forge@jonas.bernoulli.dev>
 ;; Maintainer: Jonas Bernoulli <emacs.forge@jonas.bernoulli.dev>
@@ -235,9 +235,9 @@
           (oset repo condition :tracked))
         (forge--msg repo t t   "Storing REPO")
         (cond
-         ((oref repo selective-p))
-         (callback (funcall callback))
-         ((forge--maybe-git-fetch repo buf))))
+          ((oref repo selective-p))
+          (callback (funcall callback))
+          ((forge--maybe-git-fetch repo buf))))
       :narrow '(repository)
       :until
       ;; Keys have the form `FIELD-until', where FIELD is the name of a
@@ -359,8 +359,8 @@
       [($owner String!)
        ($name  String!)]
       (repository
-      [(owner $owner)
-       (name  $name)]
+       [(owner $owner)
+        (name  $name)]
        ,(caddr (caddr (ghub--graphql-prepare-query
                        forge--github-repository-query
                        `(repository discussions (discussion . ,number)))))
@@ -375,11 +375,11 @@
     :noerror t
     :callback (lambda (data)
                 (let-alist data
-                  (cond ((setq data .data.repository.discussion)
+                  (cond ((setq data .repository.discussion)
                          (forge--update-discussion repo data))
-                        ((setq data .data.repository.issue)
+                        ((setq data .repository.issue)
                          (forge--update-issue repo data))
-                        ((setq data .data.repository.pullRequest)
+                        ((setq data .repository.pullRequest)
                          (forge--update-pullreq repo data))))
                 (forge-refresh-buffer))))
 
@@ -1234,7 +1234,7 @@
   ;; When there are multiple conflicting "default" templates, the rules
   ;; used by Github are more complex than just sorting alphabetically and
   ;; then taking the first found file.  Too bad; that's what we do.
-  (let ((branch (oref repo default-branch))
+  (let ((branch (forge--get-default-branch repo))
         (case-fold-search t))
     (seq-some (lambda (file)
                 (and (string-match-p "\
@@ -1263,11 +1263,12 @@
   (message "Waiting 5 seconds for GitHub to complete rename...done")
   (magit-call-git "fetch" "--prune" (oref repo remote)))
 
-(cl-defmethod forge--fork-repository ((repo forge-github-repository) fork)
+(cl-defmethod forge--fork-repository ((repo forge-github-repository) fork all)
   (with-slots (name apihost) repo
     (forge-rest repo "POST" "/repos/:owner/:name/forks"
       ((and (not (equal fork (ghub--username apihost)))
-            (organization fork))))
+            (organization fork))
+       (default-branch-only (not all))))
     (ghub-wait (format "/repos/%s/%s" fork name)
                nil :auth 'forge :host apihost)))
 
