@@ -1,6 +1,6 @@
 ;;; forge-repo.el --- Repository support  -*- lexical-binding:t -*-
 
-;; Copyright (C) 2018-2025 Jonas Bernoulli
+;; Copyright (C) 2018-2026 Jonas Bernoulli
 
 ;; Author: Jonas Bernoulli <emacs.forge@jonas.bernoulli.dev>
 ;; Maintainer: Jonas Bernoulli <emacs.forge@jonas.bernoulli.dev>
@@ -124,9 +124,14 @@
                    (car remotes))))
     (when (and warn config remote (not (equal config remote)))
       (message "Ignored forge.remote=%s; no such remote.\nSee %s." config
-               "https://magit.vc/manual/forge/How-Forge-Detection-Works.html"))
+               "https://docs.magit.vc/forge/How-Forge-Detection-Works.html"))
     remote))
 
+(defun forge--get-default-branch (repo)
+  (let ((default-directory (forge-get-worktree repo)))
+    (concat (forge--get-remote) "/"
+            (or (oref repo default-branch) "master"))))
+
 (cl-defmethod forge-get-repository ((_(eql :id)) id)
   (closql-get (forge-db) (substring-no-properties id) 'forge-repository))
 
@@ -175,7 +180,7 @@ or signal an error, depending on DEMAND."
                                  $ "that remote does not exist.")))
                   ((magit-list-remotes) "Cannot decide on remote to use.")
                   (t "No remote configured."))
-            "https://magit.vc/manual/forge/How-Forge-Detection-Works.html"
+            "https://docs.magit.vc/forge/How-Forge-Detection-Works.html"
             ))))))
 
 (cl-defmethod forge-get-repository ((url string) &optional remote demand)
