@@ -1,6 +1,6 @@
 ;;; forge-topic.el --- Topics support  -*- lexical-binding:t -*-
 
-;; Copyright (C) 2018-2025 Jonas Bernoulli
+;; Copyright (C) 2018-2026 Jonas Bernoulli
 
 ;; Author: Jonas Bernoulli <emacs.forge@jonas.bernoulli.dev>
 ;; Maintainer: Jonas Bernoulli <emacs.forge@jonas.bernoulli.dev>
@@ -675,16 +675,16 @@ Limit list to topics for which a review by the given user was requested."
       (and
        ,@(and (not global) repo `((= topic:repository ,(oref repo id))))
        ,@(cond
-          ((and active state status)
-           `((or (in topic:state  ,(vconcat (ensure-list state)))
-                 (in topic:status ,(vconcat (ensure-list status))))))
-          (`(,@(and state  `((in topic:state  ,(vconcat (ensure-list state)))))
-             ,@(and status `((in topic:status ,(vconcat (ensure-list status))))))))
+           ((and active state status)
+            `((or (in topic:state  ,(vconcat (ensure-list state)))
+                  (in topic:status ,(vconcat (ensure-list status))))))
+           (`(,@(and state  `((in topic:state  ,(vconcat (ensure-list state)))))
+              ,@(and status `((in topic:status ,(vconcat (ensure-list status))))))))
        ,@(pcase type
-          ((and 'discussion (guard category))
-           '((= topic:category discussion-category:id)))
-          ((and (or 'issue 'pullreq) (guard milestone))
-           '((= topic:milestone milestone:id))))
+           ((and 'discussion (guard category))
+            '((= topic:category discussion-category:id)))
+           ((and (or 'issue 'pullreq) (guard milestone))
+            '((= topic:milestone milestone:id))))
        ,@(and labels    `((or ,@(mapcar (##`(= label:name ,%)) labels))))
        ,@(and marks     `((or ,@(mapcar (##`(=  mark:name ,%))  marks))))
        ,@(and saved     '((= topic:saved-p  't)))
@@ -749,13 +749,13 @@ can be selected from the start."
                   (let (all-choices)
                     (lambda (_string)
                       (cond
-                       (all-choices)
-                       (forge-limit-topic-choices choices)
-                       (t
-                        (forge--replace-minibuffer-prompt (concat prompt ": "))
-                        (setq alist (forge--topic-collection
-                                     (forge--list-topics all repo)))
-                        (setq all-choices (mapcar #'car alist)))))))
+                        (all-choices)
+                        (forge-limit-topic-choices choices)
+                        (t
+                         (forge--replace-minibuffer-prompt (concat prompt ": "))
+                         (setq alist (forge--topic-collection
+                                      (forge--list-topics all repo)))
+                         (setq all-choices (mapcar #'car alist)))))))
                  nil t nil nil default))
             (magit-completing-read prompt choices nil t nil nil default))))
     (cdr (assoc choice alist))))
@@ -1000,23 +1000,23 @@ can be selected from the start."
   (and-let*
       ((local t)
        (labels (cond
-                ((eieio-object-p arg)
-                 (oref arg labels))
-                ((forge-buffer-repository)
-                 (forge-sql-cdr `[:select label:* :from label :where
-                                  ,(if arg
-                                       '(and (= repository $s1)
-                                             (in name $v2))
-                                     '(= repository $s1))
-                                  :order-by [(asc name)]]
-                                forge-buffer-repository
-                                (vconcat arg)))
-                (t
-                 (setq local nil)
-                 (forge-sql `[:select :distinct name :from label
-                             ,@(and arg '(:where (in name $v1)))
-                              :order-by [(asc name)]]
-                            (vconcat arg)))))
+                 ((eieio-object-p arg)
+                  (oref arg labels))
+                 ((forge-buffer-repository)
+                  (forge-sql-cdr `[:select label:* :from label :where
+                                   ,(if arg
+                                        '(and (= repository $s1)
+                                              (in name $v2))
+                                      '(= repository $s1))
+                                   :order-by [(asc name)]]
+                                 forge-buffer-repository
+                                 (vconcat arg)))
+                 (t
+                  (setq local nil)
+                  (forge-sql `[:select :distinct name :from label
+                               ,@(and arg '(:where (in name $v1)))
+                               :order-by [(asc name)]]
+                             (vconcat arg)))))
        (format (if local
                    (pcase-lambda (`(,_id ,name ,color ,_description))
                      (let* ((background (forge--sanitize-color color))
@@ -1447,12 +1447,12 @@ This mode itself is never used directly."
          (magit-insert-section (,(intern (format "topic-%s" name)))
            (insert ,(capitalize (string-pad (format "%s: " name) 11)))
            ,(cond
-             (insert
-              `(unless (funcall ,insert topic)
-                 (insert (magit--propertize-face "none" 'magit-dimmed))))
-             (format
-              `(insert (or (funcall ,format topic)
-                           (magit--propertize-face "none" 'magit-dimmed)))))
+              (insert
+               `(unless (funcall ,insert topic)
+                  (insert (magit--propertize-face "none" 'magit-dimmed))))
+              (format
+               `(insert (or (funcall ,format topic)
+                            (magit--propertize-face "none" 'magit-dimmed)))))
            (insert ?\n)))
        ,@(and (if command? command t)
               `((defvar-keymap ,map "<remap> <magit-edit-thing>"
@@ -1501,6 +1501,8 @@ This mode itself is never used directly."
 ;;; Commands
 ;;;; Groups
 
+(defvar forge--show-topic-legend t)
+
 (transient-define-group forge--lists-group
   ["List"
    ("l r" "repositories"  forge-list-repositories)
@@ -1555,8 +1557,6 @@ This mode itself is never used directly."
   ["" :if-non-nil forge--show-topic-legend
    (:info* (##propertize "draft"            'face 'forge-pullreq-draft))])
 
-(defvar forge--show-topic-legend t)
-
 (transient-define-suffix forge-toggle-topic-legend ()
   "Toggle whether to show legend for faces used in topic menus and lists."
   :description (##if forge--show-topic-legend "hide legend" "show legend")
@@ -1792,8 +1792,8 @@ inferior process."
    (definition
     :initform (lambda (value)
                 (interactive
-                 (list (funcall (oref (transient-suffix-object) reader)
-                                (forge-current-topic t))))
+                  (list (funcall (oref (transient-suffix-object) reader)
+                                 (forge-current-topic t))))
                 (let ((topic (forge-current-topic t)))
                   (funcall (oref (transient-suffix-object) setter)
                            (forge-get-repository topic)
@@ -1976,7 +1976,7 @@ When point is on the answer, then unmark it and mark no other."
 
 (defun forge--topic-template-files-1 (repo suffix &rest paths)
   (setq suffix (ensure-list suffix))
-  (let ((branch (oref repo default-branch)))
+  (let ((branch (forge--get-default-branch repo)))
     (seq-keep (if suffix
                   (##and (member (file-name-extension %) suffix)
                          (concat branch ":" %))
@@ -2083,7 +2083,7 @@ modify `bug-reference-bug-regexp' if appropriate."
 
 (unless noninteractive
   (dolist (hook forge-bug-reference-hooks)
-    (add-hook hook #'forge-bug-reference-setup)))
+    (add-hook hook #'forge-bug-reference-setup t)))
 
 ;;; _
 ;; Local Variables:
